==> qbs-src-1.4.1.zip: qbs-src-1.4.1/src/lib/corelib/language/filecontext.h <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of the Qt Build Suite.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms and
** conditions see http://www.qt.io/terms-conditions. For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QBS_FILECONTEXT_H
#define QBS_FILECONTEXT_H

#include "filecontextbase.h"
#include "item.h"

namespace qbs {
namespace Internal {

class FileContext : public FileContextBase
{
    friend class ItemReaderASTVisitor;

    FileContext();

public:
    static FileContextPtr create();

    Item *idScope() const;

private:
    Item *m_idScope;
};

inline Item *FileContext::idScope() const
{
    return m_idScope;
}

} // namespace Internal
} // namespace qbs

#endif // QBS_FILECONTEXT_H

==> qbs-src-1.5.2.zip: qbs-src-1.5.2/src/lib/corelib/language/filecontext.h <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qbs.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms and
** conditions see http://www.qt.io/terms-conditions. For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QBS_FILECONTEXT_H
#define QBS_FILECONTEXT_H

#include "filecontextbase.h"
#include "forward_decls.h"

namespace qbs {
namespace Internal {
class Item;
class ItemPool;

class FileContext : public FileContextBase
{
public:
    static FileContextPtr create();

    Item *idScope() const { return m_idScope; }
    void ensureIdScope(ItemPool *itemPool);

private:
    FileContext();

    Item *m_idScope;
};

} // namespace Internal
} // namespace qbs

#endif // QBS_FILECONTEXT_H
